Command

Enum Command 

pub enum Command {
    Init,
    Check,
    Run(RunArgs),
    Projects {
        command: Option<ProjectsCommand>,
    },
    Hooks {
        command: HooksCommand,
    },
    Doctor,
    Completions {
        shell: CompletionShell,
    },
    Hook {
        command: InternalHookCommand,
    },
}
Subcommands. Absent, muster runs the TUI.

Variants



Init

Create a starter muster.yml here and register this folder as a project.



Check

Validate the workspace config and exit non-zero on problems.



Run(RunArgs)

Register a command in a project, then run it.



Projects

List registered projects, or add and remove them.

Fields



Hooks

Install provider integrations used to preserve native agent sessions.

Fields



Doctor

Diagnose config, projects, sessions, hooks, clipboard, and completions.



Completions

Print the shell hook that enables completions.

Fields

shell: CompletionShell

Shell to print the hook for.



Hook

Internal provider-hook receiver.

Fields