add

Function add 

pub fn add(
    directory: &Path,
    registry: &dyn ProjectRegistry,
) -> Result<Vec<Row>, CliError>
Registers an existing folder that already contains a workspace file.

Errors

Returns CliError::MissingWorkspaceFile when the folder has no muster.yml, when the path is a directory, or when it is a dangling symlink - anything other than a readable regular file.