init

Function init 

pub fn init(
    directory: &Path,
    registry: &dyn ProjectRegistry,
) -> Result<Vec<Row>, CliError>
Scaffolds a starter workspace in directory and registers it as a project. Returns the report rows to print, in order.

Errors

Returns CliError when the folder name is not a usable project name or the registry cannot be read or written.