SessionRestore

Struct SessionRestore 

pub struct SessionRestore { /* private fields */ }
One durable session the active workspace should represent at startup.

Implementations

Source

impl SessionRestore

pub fn session(&self) -> &AgentSession

Durable record that remains the source of lifecycle truth.

pub fn command(&self) -> &Option<CommandLine>

Resume command when the provider identity is usable.

Source

impl SessionRestore

pub fn builder() -> SessionRestoreBuilder<((), ())>

Create a builder for building SessionRestore. On the builder, call .session(...), .command(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of SessionRestore.