pub struct SessionRestorer;Expand description
Selects durable sessions that belong in one workspace without performing I/O.
Implementations
Sourceimpl SessionRestorer
impl SessionRestorer
Sourcepub fn for_project(
sessions: impl IntoIterator<Item = AgentSession>,
project: &Path,
existing: &HashSet<AgentSessionId>,
owns_project: impl Fn(&Path, &Path) -> bool,
owner_is_live: impl Fn(&AgentSession) -> bool,
) -> Vec<SessionRestore>
pub fn for_project( sessions: impl IntoIterator<Item = AgentSession>, project: &Path, existing: &HashSet<AgentSessionId>, owns_project: impl Fn(&Path, &Path) -> bool, owner_is_live: impl Fn(&AgentSession) -> bool, ) -> Vec<SessionRestore>
Returns open or pending sessions for project not already represented by a pane.