pub struct AgentSessionId(/* private fields */);Expand description
Stable Muster-owned identity for an agent session.
Implementations
Sourceimpl AgentSessionId
impl AgentSessionId
pub fn into_inner(self) -> String
Sourceimpl AgentSessionId
impl AgentSessionId
Sourcepub fn generate() -> Result<Self, AgentSessionIdError>
pub fn generate() -> Result<Self, AgentSessionIdError>
Creates a globally unique identity for a new session.
Errors
Returns the generated newtype’s validation error if its invariant ever diverges from UUID’s non-empty textual representation.