pub struct AgentProtocolEvent { /* private fields */ }Expand description
Canonical versioned event an agent can send to muster hook capture.
Implementations
Sourceimpl AgentProtocolEvent
impl AgentProtocolEvent
Sourcepub fn version(&self) -> &u8
pub fn version(&self) -> &u8
Protocol schema version, currently AGENT_PROTOCOL_VERSION.
Sourcepub fn event(&self) -> &AgentProtocolEventKind
pub fn event(&self) -> &AgentProtocolEventKind
Lifecycle event represented by this payload.
Sourcepub fn session_id(&self) -> &NativeSessionId
pub fn session_id(&self) -> &NativeSessionId
Provider-owned identity used by its native resume command.
Sourceimpl AgentProtocolEvent
impl AgentProtocolEvent
Sourcepub fn session_started(session_id: NativeSessionId) -> Self
pub fn session_started(session_id: NativeSessionId) -> Self
Creates the canonical event for a provider conversation becoming active.