pub enum ProcessOutput {
Chunk(Vec<u8>),
Exited(ExitOutcome),
}Expand description
An event emitted by a running process, delivered to the runtime.
Variants
Chunk(Vec<u8>)
A chunk of raw bytes read from the process’s PTY.
Exited(ExitOutcome)
The process exited with the given outcome.