pub enum Command {
Init,
Check,
Run(RunArgs),
Projects {
command: Option<ProjectsCommand>,
},
Hooks {
command: HooksCommand,
},
Doctor,
Completions {
shell: CompletionShell,
},
Hook {
command: InternalHookCommand,
},
}Expand description
Subcommands. Absent, muster runs the TUI.
Variants
Init
Create a starter muster.yml here and register this folder as a project.
Check
Validate the workspace config and exit non-zero on problems.
Run(RunArgs)
Register a command in a project, then run it.
Projects
List registered projects, or add and remove them.
Fields

command: Option<ProjectsCommand>Hooks
Install provider integrations used to preserve native agent sessions.
Fields

command: HooksCommandDoctor
Diagnose config, projects, sessions, hooks, clipboard, and completions.
Completions
Print the shell hook that enables completions.
Fields

shell: CompletionShellShell to print the hook for.
Hook
Internal provider-hook receiver.
Fields

command: InternalHookCommandTrait Implementations
Sourceimpl FromArgMatches for Command
impl FromArgMatches for Command
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut<'b>(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut<'b>( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Subcommand for Command
impl Subcommand for Command
Sourcefn augment_subcommands<'b>(__clap_app: Command) -> Command
fn augment_subcommands<'b>(__clap_app: Command) -> Command
Sourcefn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
fn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourcefn has_subcommand(__clap_name: &str) -> bool
fn has_subcommand(__clap_name: &str) -> bool
Test whether
Self can parse a specific subcommandAuto Trait Implementations
impl Freeze for Command
impl RefUnwindSafe for Command
impl Send for Command
impl Sync for Command
impl Unpin for Command
impl UnsafeUnpin for Command
impl UnwindSafe for Command