pub struct RunArgs { /* private fields */ }Expand description
muster run: register a command as a process in a project, then run it.
The command is added to the project’s workspace file (so it persists and is
managed on the next launch) and then executed in place, exactly as if it had
been typed without the muster run prefix.