pub struct SessionRestore { /* private fields */ }Expand description
One durable session the active workspace should represent at startup.
Implementations
Sourceimpl SessionRestore
impl SessionRestore
Sourcepub fn session(&self) -> &AgentSession
pub fn session(&self) -> &AgentSession
Durable record that remains the source of lifecycle truth.
Sourcepub fn command(&self) -> &Option<CommandLine>
pub fn command(&self) -> &Option<CommandLine>
Resume command when the provider identity is usable.