pub enum ConfigError {
Read {
path: PathBuf,
source: Error,
},
Write {
path: PathBuf,
source: Error,
},
NoConfigDir,
Parse(Error),
InvalidStopPolicy {
kind: ProcessKind,
name: ProcessName,
},
}Expand description
Errors from loading or parsing the workspace configuration.
Variants
Read
The configuration file could not be read from disk.
Write
The configuration file could not be written to disk.
NoConfigDir
No writable config directory could be located on this platform.
Parse(Error)
The configuration was not valid YAML or violated the schema.
InvalidStopPolicy
A non-command process configured command-only graceful shutdown.
Fields

kind: ProcessKindSection containing the invalid process.

name: ProcessNameName of the invalid process.