pub struct ProcessSpec { /* private fields */ }Expand description
Declarative definition of one process within a workspace section.
Implementations
Sourceimpl ProcessSpec
impl ProcessSpec
pub fn name(&self) -> &ProcessName
pub fn command(&self) -> &Option<CommandLine>
pub fn working_dir(&self) -> &Option<PathBuf>
pub fn description(&self) -> &Option<Description>
pub fn restart(&self) -> &Option<RestartPolicy>
Sourcepub fn stop(&self) -> &Option<StopPolicy>
pub fn stop(&self) -> &Option<StopPolicy>
Optional graceful shutdown policy. Only command specs may configure it.
Sourceimpl ProcessSpec
impl ProcessSpec
pub fn with_name(self, val: ProcessName) -> Self
pub fn with_command(self, val: Option<CommandLine>) -> Self
pub fn with_working_dir(self, val: Option<PathBuf>) -> Self
pub fn with_description(self, val: Option<Description>) -> Self
pub fn with_restart(self, val: Option<RestartPolicy>) -> Self
Sourcepub fn with_stop(self, val: Option<StopPolicy>) -> Self
pub fn with_stop(self, val: Option<StopPolicy>) -> Self
Optional graceful shutdown policy. Only command specs may configure it.
Sourcepub fn with_autostart(self, val: Option<bool>) -> Self
pub fn with_autostart(self, val: Option<bool>) -> Self
Whether to launch this process automatically on load. Absent means the
per-kind default; true/false overrides it.
Sourceimpl ProcessSpec
impl ProcessSpec
Sourcepub fn builder() -> ProcessSpecBuilder<((), (), (), (), (), (), ())>
pub fn builder() -> ProcessSpecBuilder<((), (), (), (), (), (), ())>
Create a builder for building ProcessSpec.
On the builder, call .name(...), .command(...)(optional), .working_dir(...)(optional), .description(...)(optional), .restart(...)(optional), .stop(...)(optional), .autostart(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of ProcessSpec.
Sourceimpl ProcessSpec
impl ProcessSpec
Sourcepub fn to_process(&self, id: PaneId, kind: ProcessKind) -> Process
pub fn to_process(&self, id: PaneId, kind: ProcessKind) -> Process
Builds the corresponding Process entity in its initial Pending state.
Sourcepub fn restart_policy(&self) -> RestartPolicy
pub fn restart_policy(&self) -> RestartPolicy
The effective restart policy, treating an absent policy as Never.
Sourcepub fn should_autostart(&self, kind: ProcessKind) -> bool
pub fn should_autostart(&self, kind: ProcessKind) -> bool
Whether this process auto-starts. Defaults to false for commands (which wait for an explicit start) and true for agents and terminals.
Sourcepub fn effective_stop_policy(&self, kind: ProcessKind) -> Option<StopPolicy>
pub fn effective_stop_policy(&self, kind: ProcessKind) -> Option<StopPolicy>
The effective graceful shutdown policy for kind. Commands use the
domain default when the config omits stop; other kinds have no policy.